# Cas 客户端

> Cas 支持多种客户端的接入，每种客户端的接入方式都有所差别，根据接入项目的情况来选择还是的接入客户端。

- Apache httpd Server ([mod_auth_cas module](https://github.com/apereo/mod_auth_cas "mod_auth_cas module"))
- Java ([Java CAS Client](https://github.com/apereo/java-cas-client "Java CAS Client"))
- .NET ([.NET CAS Client](https://github.com/apereo/dotnet-cas-client ".NET CAS Client"))
- PHP ([phpCAS](https://github.com/apereo/phpCAS "phpCAS"))
- Perl (PerlCAS)
- Python (pycas)
- Ruby (rubycas-client)
- Shiro ([shiro-cas](https://github.com/hiwepy/shiro-cas-spring-boot-starter "shiro-cas"))
- Spring Security (spring-security-cas)

| 客户端  | 应用场景  | 项目地址  |   |
| ------------ | ------------ | ------------ | ------------ |
| cas-client-core |  未使用鉴权框架的Java Web 项目  |  https://github.com/apereo/java-cas-client |   |
| phpCAS  | 使用PHP编程语言开发的 Web 项目  | https://github.com/apereo/phpCAS  |   |
| .NET CAS Client  | 使用.NET 编程语言开发的 Web 项目  | https://github.com/apereo/dotnet-cas-client  |   |
| shiro-cas  | 使用了shiro鉴权框架的Java Web 项目  |  https://github.com/hiwepy/shiro-cas-spring-boot-starter |   |
| spring-security-cas  | 使用了spring-security鉴权框架的Java Web 项目  |   |   |


#### Cas 协议交互流程

CAS 的核心就是其 Ticket，及其在 Ticket 之上的一系列处理操作

> ST（Service Ticket）
    ST 是 CAS 为用户签发的访问某一 service（即集成 CAS 单点登录验证的应用系统资源 url）的票据
  TGT（Ticket Grangting Ticket）
    TGT 是 CAS 为用户签发的登录票据，拥有 TGT，就代表用户已登录
  TGC（Ticket Granted Cookie)：在服务器缓存中查询 TGT 的键
    LT：Login Ticket，在每次登录前生成的一个唯一的票根，仅用作登录验证

##### 未登录统一身份认证平台

```seq
participant 用户
participant 浏览器
participant 统一身份认证平台
participant 系统B
浏览器 -> Cas客户端: 首次访问“业务系统/平台”
Cas客户端 -> Cas客户端: 查找 Session 的 CONST_CAS_ASSERTION，无
Cas客户端 -> Cas客户端: 查找 ticket 参数，无
Cas客户端 -> Cas客户端: no ticket and no assertion found
Cas客户端 --> 浏览器: 构造重定向 url
浏览器 -> 统一身份认证平台: 重定向 https://cas_server_url/cas/login?service=xxx，无 TGC
统一身份认证平台 -> 统一身份认证平台: 通过 TGC 查询 TGT
统一身份认证平台 -> 统一身份认证平台:  查询失败
统一身份认证平台 --> 浏览器: 重定向到统一身份认证平台登录界面
浏览器 -> 统一身份认证平台: POST 请求 https://cas_server_url/cas/login?service=xxx，附带 username、password、lt、execution、_eventId 参数 
统一身份认证平台 -> 统一身份认证平台:  验证用户数据库，验证成功
统一身份认证平台 -> 统一身份认证平台:  生成并缓存 TGT
统一身份认证平台 --> 浏览器: COOKIE 存储 TGC，签发一个 ST
浏览器 -> Cas客户端: 重定向 URL：service?ticket=ST ，例如：https://cas_client_url/home?ticket=ST
Cas客户端 -> Cas客户端: 查找 Session 的 CONST_CAS_ASSERTION，无
Cas客户端 -> Cas客户端: 查找 ticket 参数，有
Cas客户端 -> 统一身份认证平台: 调用统一身份认证平台：https://cas_server_url/cas/serviceValidate，验证 ST
统一身份认证平台--> Cas客户端: ST 认证成功
Cas客户端 -> Cas客户端: Session 存入 CONST_CAS_ASSERTION
Cas客户端 -> 浏览器: ST 认证成功后需要重定向
Cas客户端 --> 浏览器: 重定向 URL：service ，例如：https://cas_client_url/home
Cas客户端 --> 浏览器: 返回访问资源
浏览器 -> Cas客户端: 后续请求
Cas客户端 -> Cas客户端: 查找 Session 的 CONST_CAS_ASSERTION，有
Cas客户端 --> 浏览器: 返回访问资源
```

##### 已登录统一身份认证平台

```seq
浏览器 -> Cas客户端: 第一次请求访问“业务系统/平台”
Cas客户端 -> Cas客户端: 查找 Session 的 CONST_CAS_ASSERTION，无
Cas客户端 -> Cas客户端: 查找 ticket 参数，无
Cas客户端 -> Cas客户端: no ticket and no assertion found
Cas客户端 --> 浏览器: 构造重定向 url
浏览器 -> 统一身份认证平台: 重定向 https://cas_server_url/cas/login?service=xxx，有 TGC
统一身份认证平台 -> 统一身份认证平台: 通过 TGC 查询 TGT
统一身份认证平台 -> 统一身份认证平台:  查询成功
统一身份认证平台 --> 浏览器: 签发一个 ST
浏览器 -> Cas客户端: 重定向 URL：service?ticket=ST ，例如：https://cas_client_url/home?ticket=ST
Cas客户端 -> Cas客户端: 查找 Session 的 CONST_CAS_ASSERTION，无
Cas客户端 -> Cas客户端: 查找 ticket 参数，有
Cas客户端 -> 统一身份认证平台: 调用统一身份认证平台：https://cas_server_url/cas/serviceValidate，验证 ST
统一身份认证平台--> Cas客户端: ST 认证成功
Cas客户端 -> Cas客户端: Session 存入 CONST_CAS_ASSERTION
Cas客户端 -> 浏览器: ST 认证成功后需要重定向
Cas客户端 --> 浏览器: 重定向 URL：service ，例如：https://cas_client_url/home
Cas客户端 --> 浏览器: 返回访问资源
浏览器 -> Cas客户端: 后续请求
Cas客户端 -> Cas客户端: 查找 Session 的 CONST_CAS_ASSERTION，有
Cas客户端 --> 浏览器: 返回访问资源
```